==> ulyxex.0.1.1.with-tinyMce.zip: pages/code/action_links.php <==
<?php
/****************************************/
$act = array(
	1=>$h->ahref("admin.php?action=admin_home",$tr->w("admin home"),"class='action'"),
	2=>$h->ahref("admin.php?action=articles",$tr->w("articles"),"class='action'"),
	3=>$h->ahref("admin.php?action=multiples_uploads",$tr->w("uploads"),"class='action'"),
	4=>$h->ahref("admin.php?action=pages",$tr->w("pages"),"class='action'"),
	5=>$h->ahref("admin.php?action=links",$tr->w("links"),"class='action'"),
	6=>$h->ahref("admin.php?action=users",$tr->w("users"),"class='action'"),
	7=>$h->ahref("admin.php?action=modify_user&user=".$_SESSION['userid'],$tr->w("my user profile"),"class='action'"),
	8=>$h->ahref("http://ulyxex.logz.org/index.php?page=3",$tr->w("help"),"class='action'"),
	9=>$h->ahref("login.php",$tr->w("login"),"class='action'"),
	10=>$h->ahref("logout.php",$tr->w("logout"),"class='action'")
);
/* level 1 all privileges and website 	*/
/* parameters							*/
$actionsLinksLevel1 = implode(" ",array($act[1],$act[2],$act[3],$act[4],$act[5],$act[6],$act[7],$act[8],$act[9],$act[10]));
/* level 2 create pages and write		*/
/* articles everywhere 					*/
$actionsLinksLevel2 = implode(" ",array($act[2],$act[3],$act[4],$act[5],$act[7],$act[8],$act[9],$act[10]));
/* level 3 create pages and write		*/
/* articles only in owner pages			*/
$actionsLinksLevel3 = implode(" ",array($act[2],$act[3],$act[7],$act[8],$act[9],$act[10]));
/* level 4 only write articles in		*/
/* sandbox								*/
$actionsLinksLevel4 = implode(" ",array($act[2],$act[7],$act[8],$act[9],$act[10]));
/* array								*/
$actionsLinks = array("",$actionsLinksLevel1,$actionsLinksLevel2,$actionsLinksLevel3,$actionsLinksLevel4);
?>

==> ulyxex.0.1.2.with-tinyMce.zip: pages/code/action_links.php <==
<?php
/****************************************/
$act = array(
	1=>$h->ahref("admin.php?action=admin_home",$tr->w("admin home"),"class='action'"),
	2=>$h->ahref("admin.php?action=articles",$tr->w("articles"),"class='action'"),
	3=>$h->ahref("admin.php?action=multiples_uploads",$tr->w("uploads"),"class='action'"),
	4=>$h->ahref("admin.php?action=pages",$tr->w("pages"),"class='action'"),
	5=>$h->ahref("admin.php?action=links",$tr->w("links"),"class='action'"),
	6=>$h->ahref("admin.php?action=users",$tr->w("users"),"class='action'"),
	7=>$h->ahref("admin.php?action=modify_user&user=".$_SESSION['userid'],$tr->w("my user profile"),"class='action'"),
	8=>$h->ahref("http://ulyxex.logz.org/index.php?navpage=3",$tr->w("help"),"class='action'"),
	9=>$h->ahref("login.php",$tr->w("login"),"class='action'"),
	10=>$h->ahref("logout.php",$tr->w("logout"),"class='action'")
);
/* level 1 all privileges and website 	*/
/* parameters							*/
$actionsLinksLevel1 = implode(" ",array($act[1],$act[2],$act[3],$act[4],$act[5],$act[6],$act[7],$act[8],$act[9],$act[10]));
/* level 2 create pages and write		*/
/* articles everywhere 					*/
$actionsLinksLevel2 = implode(" ",array($act[2],$act[3],$act[4],$act[5],$act[7],$act[8],$act[9],$act[10]));
/* level 3 create pages and write		*/
/* articles only in owner pages			*/
$actionsLinksLevel3 = implode(" ",array($act[2],$act[3],$act[7],$act[8],$act[9],$act[10]));
/* level 4 only write articles in		*/
/* sandbox								*/
$actionsLinksLevel4 = implode(" ",array($act[2],$act[7],$act[8],$act[9],$act[10]));
/* array								*/
$actionsLinks = array("",$actionsLinksLevel1,$actionsLinksLevel2,$actionsLinksLevel3,$actionsLinksLevel4);
?>
